from dock_r.main import (
    login,
    tag,
    build,
    tag,
    push,
    pull,
    exists_locally,
    exists_remotely,
    remote_retag,
    ecs_retag,
    ecs_submit,
    get_ecs_log_url,
    get_ecs_task_detail_url,
    ecs_wait_for_start,
    ecs_wait_for_stop,
)
